@@ -1,5 +1,8 @@
 import io
 import json
+import logging
+
+log = logging.getLogger(__name__)
 
 
 class Stream(object):
@@ -12,7 +15,6 @@ class Stream(object):
 
     def __init__(self, session):
         self.session = session
-        self.logger = self.session.logger.new_module("stream.".format(self.shortname()))
 
     def __repr__(self):
         return "<Stream()>"
