@@ -1,4 +1,5 @@
 import argparse
+import numbers
 import re
 from string import printable
 from textwrap import dedent
@@ -44,6 +45,37 @@ class ArgumentParser(argparse.ArgumentParser):
         elif name:
             yield u"--{0}".format(name)
 
+    def _match_argument(self, action, arg_strings_pattern):
+        # - https://github.com/streamlink/streamlink/issues/971
+        # - https://bugs.python.org/issue9334
+
+        # match the pattern for this action to the arg strings
+        nargs_pattern = self._get_nargs_pattern(action)
+        match = argparse._re.match(nargs_pattern, arg_strings_pattern)
+
+        # if no match, see if we can emulate optparse and return the
+        # required number of arguments regardless of their values
+        if match is None:
+            nargs = action.nargs if action.nargs is not None else 1
+            if isinstance(nargs, numbers.Number) and len(arg_strings_pattern) >= nargs:
+                return nargs
+
+        # raise an exception if we weren't able to find a match
+        if match is None:
+            nargs_errors = {
+                None: argparse._('expected one argument'),
+                argparse.OPTIONAL: argparse._('expected at most one argument'),
+                argparse.ONE_OR_MORE: argparse._('expected at least one argument'),
+            }
+            default = argparse.ngettext('expected %s argument',
+                                        'expected %s arguments',
+                                        action.nargs) % action.nargs
+            msg = nargs_errors.get(action.nargs, default)
+            raise argparse.ArgumentError(action, msg)
+
+        # return the number of arguments matched
+        return len(match.group(1))
+
 
 class HelpFormatter(argparse.RawDescriptionHelpFormatter):
     """A nicer help formatter.
@@ -465,6 +497,9 @@ def build_parser():
             gaming oriented platforms. "Game being played" is a way to categorize
             the stream, so it doesn't need its own separate handling.
 
+        {{url}}
+            URL of the stream.
+
         Examples:
 
             %(prog)s -p vlc --title "{{title}} -!- {{author}} -!- {{category}} \\$A" <url> [stream]
@@ -1035,7 +1070,8 @@ def build_parser():
         "--http-proxy",
         metavar="HTTP_PROXY",
         help="""
-        A HTTP proxy to use for all HTTP requests.
+        A HTTP proxy to use for all HTTP requests, including WebSocket connections. 
+        By default this proxy will be used for all HTTPS requests too.
 
         Example: "http://hostname:port/"
         """
